---
tags:
- market making
- ⛏️ liquidity mining strategy
---

# `pure_market_making`

## 📁 [策略目录](https://github.com/CoinAlpha/hummingbot/tree/master/hummingbot/strategy/pure_market_making)

## 📝 综述

## 它是如何运作

该策略允许Hummingbot用户在`现货`交易中对单个交易对运行做市策略。

它以相对于中间价格的价格在订单簿上发出限价买入(bid)和限价卖出(ask)订单价差等于 `bid_spread`(买单价差) 和 `ask_spread`(卖单价差). 每个 `order_refresh_time`(订单刷新时间) 秒, 该策略用更新价差和订单数量的新订单替换现有订单。 

此外，该策略还包含一些参数，使交易者能够控制如何根据库存位置下订单，使用来自不同订单簿的价格，等等。

## 🏦 交易所支持

[`现货` 交易所](/exchanges/#spot)

## 👷 维护

* 发布: [0.7.0](/release-notes/0.7.0/) CoinAlpha
* 维护者: CoinAlpha

## 🛠️ 策略配置

[Config map](https://github.com/hummingbot/hummingbot/blob/master/hummingbot/strategy/pure_market_making/pure_market_making_config_map.py)

| 参数                    | 类型        | 默认值     | 新建时提示? | 提示                                                 |
|------------------------------|-------------|-------------|-------------|--------------------------------------------------------|
| `exchange`                   | string      |             | True        | 输入你的现货交易所 |
| `market`                     | string      |             | True        | 输入你想在[交易所]上交易的代币交易对 |
| `bid_spread`                 | decimal     |             | True        | 你想在离中间价多远的地方下第一个买单？ |
| `ask_spread`                 | decimal     |             | True        | 你想在离中间价多远的地方下第一个卖单？ |
| `order_refresh_time`         | float       |             | True        | 你想多久刷新买单价格和买单价格（以秒为单位）？ |
| `order_amount`               | decimal     |             | True        | 每个订单数量是多少？ |
| `ping_pong_enabled`          | bool        | False       | True        | 你想使用乒乓功能并在成交后让买卖交替执行吗？ |
| `order_levels`               | int         | 1           | False       | 买卖两边要下多少个订单？ |
| `order_level_amount`         | decimal     | 0           | False       | 你希望为每个额外订单增加或减少多少订单数量？ |
| `order_level_spread`         | decimal     | 0           | False       | 输入额外订单的价格增量（百分比）？ |
| `filled_order_delay`         | decimal     | 60          | False       | 如果你的订单成交了，你希望在下一个订单之前等待多长时间（以秒为单位）？ |
| `max_order_age`              | float       | 1800        | False       | 输入你希望以相同价格取消和替换买单和卖单的频率（以秒为单位）？ |
| `order_refresh_tolerance_pct`| decimal     | 0           | False       | 输入每个周期刷新订单所需的价格变化百分比 |
| `inventory_skew_enabled`     | bool        | False       | False       | 你想启用库存倾斜吗？ |
| `inventory_target_base_pct`  | decimal     | 50          | False       | 你的目标基础资产百分比是多少？ |
| `inventory_range_multiplier` | decimal     | 50          | False       | 以总订单量的倍数表示，围绕目标基础资产的可容忍库存范围是多少？ |
| `hanging_orders_enabled`     | bool        | False       | False       | 你要启用挂起订单吗？ |
| `hanging_orders_cancel_pct`  | decimal     | 10          | False       | 挂起订单会在达到多少价差百分比（从中间价计算）被取消？|
| `order_optimization_enabled` | bool        | False       | False       | 你想启用最佳出价跳跃吗？ |
| `ask_order_optimization_depth`| decimal    | 0           | False       | 为了计算最低卖出价，你想在订单簿中忽略顶部的灰尘订单的深度(以基础资产金额表示)？|
| `bid_order_optimization_depth`| decimal    | 0           | False       | 为了计算最高买入价，你想在订单簿中忽略顶部的灰尘订单的深度(以基础资产金额表示)？|
| `price_ceiling`              | decimal     | -1          | False       | 输入价格，超出此价格讲只挂卖单 |
| `price_floor`                | decimal     | -1          | False       | 输入价格，低于此价格讲只挂买单 |
| `price_source`               | string      | current_market| False     | 使用哪种价格来源？(current_market（当前市场） / external_market（外部市场） / custom_api（定制API)? |
| `price_type`                 | string      | mid_price   | False       | 使用哪种价格类型？(mid_price（中间价）/last_price（最后成交价）/last_own_trade_price（最后自成交价）/best_bid（买一价）/best_ask（卖一价）/inventory_cost（成本价）) |
| `price_source_exchange`      | string      |             | False       | 输入外部交易所名称 |
| `price_source_market`        | string      |             | False       | 输入[外部交易所]的交易对 |
| `price_source_custom_api`    | string      |             | False       | 输入自定义价格API地址 |
| `custom_api_update_interval` | float       | 5           | False       | 输入自定义价格更新间隔 (默认: 5.0, 最小: 0.5) |
| `inventory_price`            | decimal     | 1           | False       | 你的基本资产库存的价格是多少？ |
| `add_transaction_costs`      | bool        | False       | False       | 你是否想要将交易成本自动添加到订单价格中？ |
| `minimum_spread`             | decimal     | -100        | False       | 机器人自动取消订单的最小价差是多少? |
| `take_if_crossed`            | bool        | False       | False       | 是否挂taker单? |
| `order_override`             | bool        | None        | False       |  |

## 📓 描述

[交易逻辑](https://github.com/hummingbot/hummingbot/blob/master/hummingbot/strategy/pure_market_making/pure_market_making.pyx)

!!! 注意 "大致理念"
    下面的描述是这个策略的大致理念. 请审阅上面的**交易逻辑**中的代码去确切地理解它是如何工作的。

### 架构

Hummingbot中内置的纯做市策略会定期从可配置的订单定价和数量插件中请求限价订单建议，并通过取消现有限价订单来定期刷新订单。

以下是内置的纯做市策略内部逻辑流程的一个高级视图。

![Figure 5: Pure market making strategy logical flowchart](https://docs.hummingbot.org/assets/img/pure-mm-flowchart.svg)

纯做市策略以一种逐笔报价的方式运作。每个tick通常为1秒，尽管它可以通过编程修改为更长或更短的持续时间。

在每一个tick，纯做市策略将首先查询订单过滤器插件是否继续。假设答案是肯定的，那么它将查询订单定价和订单数量插件，并计算是否以及应该发出什么样的订单。与此同时，它还将查看之前在市场上发布的限价订单，并决定是否应该取消这些订单。

这个过程在每一个tick都重复进行，于是，根据订单定价和订单数量插件提出的提议，限价单不断被提交和撤销。

### 刷新订单

对于由纯做市策略发出的每个限价订单，将为该订单生成一个到期时间戳，该策略将跟踪该订单。新订单的到期时间通过`order_refresh_time`参数配置。
在订单到期之后，纯做市策略将为该订单创建一个取消订单提议。

### 执行订单建议

在从插件和内部刷新订单逻辑收集所有订单定价、修改和取消订单提议后 - 纯做市策略逻辑将合并所有提议并执行它们。

### 示例订单流

下面是一个关于纯做市策略如何在几个tick内起作用的假设示例。
- 在tick=`t`时，买入方和卖出方可能都存在限价订单，而且都还没有到期。新订单的建议大小为0，并且没有取消订单的建议。所以策略在这个tick不会做任何事。
- 在tick=`t+1`时，限价买入单已过期。策略将马上为过期的买入订单生成一个取消订单的提议。然后，取消订单指令将被发送到交易所并执行。
- 在tick=`t+2`时，该策略在其交易逻辑中循环，并注意到出价方不再有指令。它会为新的投标订单提出一个非零的订单规模。让我们假设现有的请求订单还没有过期，因此在此时钟滴答时不会生成取消建议。在执行阶段，该策略将简单地从当前市场的中间价格计算出一个投标订单。这样就刷新了投标顺序。

只要策略在运行，这个订单创建和订单取消的循环就会不断重复。如果一个限价单完全成交了，该策略将在下一个tick刷新它。


