虽然我们撰写了最初的[白皮书](https://hummingbot.io/liquidity-mining.pdf)并创造了“流动性挖矿”这个术语，但随着[Balancer](https://balancer.finance/)、[Curve](https://www.curve.fi/)的出现，这个概念最近在DeFi中变得流行起来。此外，尽管[Uniswap](https://uniswap.org/)在这一领域起步较晚，但它最近在最初的自动造市商(AMM)概念中引入了代币发行。

我们的流动性挖矿版本和DeFi有相同的目标:***为项目方和协议找到一种有效的方式，为数字资产提供流动性***。由于代币资产、交易所和交易所协议数量庞大且不断增长，代币流动性长期以来一直是加密货币市场的一个问题，与此同时，能够服务于该市场的复杂(且昂贵)对冲基金和做市商数量有限。

>**Hummingbot Miners和AMM流动性挖矿都采用去中心化、众包的方式做市。它们允许普通公众>(而不仅仅是专业做市商)参与为数字资产提供流动性**。

他们实现这一目标的一个重要方式是建立一个框架来补偿分散的做市商群体。

读这篇文章的大多数读者可能已经意识到，流动性挖矿协议和Hummingbot Miner提供的收益率有望达到数十至数百个百分点。**但它们是真的吗?问题是什么?**

在这篇文章中，我们将讨论通过DeFi AMM和Hummingbot Miners参与流动性挖矿的考虑因素:这两种不同方法的优点、缺点和风险。

## AMMs……回顾

自动做市商(AMMs)是DeFi最近的一项创新，它引入了一种新的、通过智能合约实现的简单做市形式。自动做市商是持有资产(统称为“流动性池”)并允许这些资产之间进行交易的智能合约。

资产在AMM上交换的价格由一个简单的公式决定，该公式参考了流动性池中每种资产的多少。最简单的模型是由Vitalik Buterin提出并由Uniswap推广的“恒定产品做市商模型”(XYK)。要了解更多关于amm工作原理的细节和细节，这里有一些很棒的文章:[《怎么解释的自动做市商的崛起》](https://medium.com/dragonfly-research/what-explains-the-rise-of-amms-7d008af1c399)。

特别在这篇文章中，需要注意的是，**对于amm来说，传统的做市概念分为两个功能:(1)提供资产/库存，(2)决定交易定价**。在传统的做市中，做市商同时承担这两种功能。

对于amm来说，准做市商的表现只能排在第一:它们只是向用于交易的智能合约存放资产并提供资产。如上所述，价格的确定(第2点)和贸易的便利实际上是由智能合约本身完成的，使用预先编程的方程。事实上，在AMM中提供资产的参与者被指定为*“流动性提供者”*，而不是做市商，这反映出他们参与的范围更为有限。

由于智能合约只是一组规则和指令，实际上它自己并不做任何事情，因此它依赖于外部第三方，即套利者。由于AMM是被动的，它要求套利者与之进行交易，以改变流动性池的组成，如果你还记得，流动性池决定了AMM的交易所价格，以及它们最终应如何与市场价格保持一致。

流动性提供者将资产存入一个资产管理平台，并按比例分享资产池的股份。因此，流动性提供者与传统做市商面临同样的主要风险:库存风险。

即使没有任何交易，池子中的资产价值也会下降(相对于一些基准资产，例如美元)。而且，由于流动性池的组成会随着交易而变化，持有或积累价值下降的资产也存在风险(例如，套利者将贬值的“坏”资产交易到AMM中，同时取出(相对)升值的“好”资产)。

此外，由于amm需要套利者才能运作，它们本质上(从定义上)是在“把钱留在桌上”。套利是一种零和博弈;如果套利者通过AMM交易获取利润，那么利润必须来自某个地方。如果你是一个流动资金提供者，那么你会感到惊讶的!利润来自于*你*。

>**如果你交易的另一方是套利者，你很可能在赔钱……**

有很多博客和研究"无常损失"，试图量化在AMM中充当流动性提供者的经济学，如[Uniswap: A Good Deal for Liquidity Providers?](https://medium.com/@pintail/uniswap-a-good-deal-for-liquidity-providers-104c0b6816f2)”以及[A primer on constant product matching markets.](http://gdre.leo-univ-orleans.fr/direr/paper/Uniswap_v2.pdf)。

这些分析通常会显示如下图表:

![](https://d33wubrfki0l68.cloudfront.net/aaec71bdca9dc012e4001689173956c9db1d6bdc/bb178/static/e9f87a6088b6a235cc016379eaa4f126/b996f/image1.png)

来源:[Uniswap: A Good Deal for Liquidity Providers? ](https://medium.com/@pintail/uniswap-a-good-deal-for-liquidity-providers-104c0b6816f2)

这张图显示的是，在流动性提供者将资产存入流动性池的时刻，资产价值的变化从0%开始，而资产的价格(x轴)是100%(当然，什么都没有发生)。

一旦交易发生导致价格上升或下降(沿着x轴移动)，锁定代币的总价值将下降，无论价格方向，沿着曲线的路径。只有当价格最终恢复到存入代币时的原始价格时，流动性提供者才会回到盈亏平衡。

🤔***等等……什么?如果价格上升或下降，我就会赔钱，如果价格恢复到初始价格，我最多也能保本?为什么会有人这么做?***

**协议费用**:为了补偿这种风险，AMM向使用协议的交易员收取费用，这些费用在流动性提供者之间积累和共享。Uniswap一开始收取0.3%的差价。然而，正如上面引用的研究所示，0.3%的费用根本不足以弥补临时性损失风险。

**业绩很难衡量**:监控一个流动性提供者的利润和基准并不是那么简单。如果资产价格走高，池子价值就会上升。下面是另一种看待流动性池价值的方式;下图显示了200次模拟交易后池子的绝对值(蓝色)，与没有交易时原始资产的价值(红色)相比(即HODL,长期持有):

![](https://d33wubrfki0l68.cloudfront.net/4b7383bf542fafbb3812f7b821ad186bbf81f32d/bcd6c/static/8c828a4a7e950e0aad31ffd3b8ebf754/b996f/image3.png)

当价格上涨时，许多流动性提供者可能很高兴他们的投资组合价值增加了，他们可能没有意识到或关注这样一个事实:如果他们什么都不做，他们的资产的价值实际上会更高。如果资产价格下跌，那就归咎于市场。做点什么和不做什么只会在市场更大的波动中迷失!一些流动性提供者可能会相信,0.3%的补偿已经足够且“做点什么”比“无所事事”更好,但在现实中已经提到,0.3%的协议费用可能不足以补偿流动性提供者的资产波动（除了稳定币之外的任何资产波动）。

**协议支持者/项目方**:流动性提供者不一定是利润驱动的。一些银行可能提供流动性，即使这会导致投资组合损失，因为它们希望推广AMM协议的使用。此外，项目方可能为其代币提供资金，以增加其代币的可访问性和可交易性。他们甚至可能使用一个AMM来“上市”他们的代币，并让它们首次向公众开放，以避免上市费用和中心化交易所的做市要求。

**代币奖励**:好吧，上面的理由可能对大多数普通公众来说没有说服力。所以现在我们开始了解AMM协议在过去几个月爆炸性增长的真正原因。归根结底就是……现金。或者更确切地说，**代币奖励**。

![](https://d33wubrfki0l68.cloudfront.net/469d8fe2b898fb4a2a705dd90b4782628cefcf6c/a7c19/static/f46d2f5970a6350f782be98a8af61fcd/cdb69/image5.jpg)

引入了流动性挖矿奖励之后，像Balancer和Curve.Fi这样的AMMs真的爆发了了。除了协议交易费用，流动性提供者还获得了慷慨的协议代币分配，以补偿无常损失，而且还远不止于此。慷慨的流动性挖矿激励使得流动性提供者不再真正需要考虑太多无常损失。

>**提供的慷慨的流动性挖矿代币奖励，加上参与的便捷性，推动了DeFi和流动性池参与的巨大增长**。

**Hummingbot Miner:中心化交易所的流动性挖矿**

![](https://d33wubrfki0l68.cloudfront.net/c5794e3846400fb56d6a60e4b12aa997e6c1c9fb/7919a/static/a15d0330ec16982b8eede3fa271c4da3/cdb69/image2.jpg)

**Hummingbot Miner**是我们的平台，我们使项目方和交易所能够为做市商和交易员为特定代币提供流动性和订单记录深度而获得的奖励池提供资金。与amm不同，我们的平台不是智能合约协议;它是一个交易数据基础平台可以***在中心化交易所进行流动性挖矿***。

>Hummingbot Miners为更多的发行人、交易所和交易对带来流动性挖矿;代币不一定非得是ERC20代币，我们可以为在中心化交易所上市的任何代币对运行流动性挖矿活动。***Hummingbot Miner可以覆盖更多的市场***。
*得分牌:Hummingbot Miner 1,AMMs 0*

话虽如此，由于在amm上建立流动性挖矿程序更容易，目前在amm上建立的流动性挖矿程序更多。我们正在努力推出新的宣传活动，并将其扩展到更多的交易所，这一工作目前仍在进行中。

>**目前在amm上存在的流动性挖矿程序比蜂鸣器矿工更多。**

*得分牌:Hummingbot Miner 1，AMMs 1*

由于我们的平台是针对中心化交易所的，参与交易的做市商和交易员必须在中心化交易所订单簿上下订单，以传统的方式进行交易。为了实现这一点，用户可以使用Hummingbot(或任何其他交易机器人)来自动化他们的交易，以便不断刷新订单簿中的订单，并管理他们的交易资产库存。

>虽然amm的流动性挖矿是被动的、不干涉的(先存放资产，然后坐等)，但中心化交易所的流动性挖矿更为复杂，需要更多的动手操作。交易员需要建立交易机器人，监控交易，并随着时间的推移调整他们的策略。*参与一个流动性池比参与Hummingbot Miner要容易得多。*

*得分牌:Hummingbot Miner1,AMMs 2*

**库存风险vs. AMM无常损失**

做市的主要风险是库存风险。我们最近在博客上写了一篇关于这个问题的文章:[什么是库存风险?](https://hummingbot.io/blog/2020-10-inventory-risk/)在我们的博客中，我们解释了做市商的资产即使不进行交易也存在价值下降的风险(“市场风险”)，还有库存风险;由于交易(和订单的完成)，做市商有可能在价值下跌的错误时间积累更多资产。***和流动性提供者一样，做市商也容易受到套利者的影响***。

但一个很大的区别是，参与Hummingbot Miners项目的交易员并不只是被动地依赖于严格的智能合约，而没有任何风险管理措施;Hummingbot Miners可以定制他们的策略，将他们的交易观点嵌入到机器人中，并实施风险管理措施。用交易员的话说，他们可以“*add alpha*”。

例如，如果价格呈下降趋势，amm将继续接受不利的交易。另一方面，使用Hummingbot，我们有许多风险管理功能，如调整买卖价差、订单定价、订单规模(买卖)，以及在一边增加订单延迟或停止订单(例如，在价格持续下跌时停止投标)。请在我们的[博客](https://hummingbot.io/blog/2020-10-inventory-risk/)中阅读更多关于这些功能的内容。

>虽然在中心化交易所做市(Hummingbot Miners)确实带来了更多的复杂性，但好处是，***交易者对自己的交易有更多的权力和控制。Hummingbot允许风险管理***!

*得分牌:Hummingbot Miner 2,AMMs 2*

**收益率**

Hummingbot Miner仍然是一个相对较新的系统，对用户来说是一个更复杂的系统。其结果是，流动性挖矿者的数量以及所配置的资产仍然有限。另一方面，AMM的流动性挖矿出现了一个大爆发，大量的流动性提供者参与和提供资产。因此，AMM流动性挖矿的收益率一直在下降，而Hummingbot Miner的收益率仍相当高。要比较目前可用的产量，请查看[Hummingbot Miner](https://miners.hummingbot.io/)和[CoinMarketCap yield farming](https://coinmarketcap.com/yield-farming/)。

>Hummingbot Miner的产量目前超过了AMM流动性挖矿的产量。

*得分牌:Hummingbot Miner 3,AMMs 2*

**基于风险的回报=可定制的风险容忍度**

与流动性池类似，使用更多的资产进行交易，以及在更长的时间内进行交易，可以让Hummingbot Miner赚到更多的钱，积累更多的回报。但除此之外，Hummingbot Miner的奖励也是基于订单的价差;矿工使用的价差越窄，他们获得的回报就越多。这使做市商的奖励与他们愿意承担的风险相结合又增加了一个维度。

例如，新的或更保守的用户可以通过创建价差更大的订单来使用更安全的交易设置。即使在更大范围内，这些矿工仍能获得回报。与此同时，更高级的用户和/或风险承受度更高的矿商可以利用更窄的价差进行更激进的交易。他们承担的风险越高(向市场提供的流动性也越好)，作为回报，他们获得的回报比例就越高。

>**Hummingbot Miner奖励允许矿工以他们期望的风险水平参与**

*得分牌:Hummingbot Miner 4,AMMs 2*

## 结论

在DeFi中挖掘流动性真的很简单;只需将资产存入智能合约，您就可以开始运行了。但是不要让这种简单欺骗了你;作为流动性提供者仍然需要承担相当大的风险，与正常的做市商有很多相同的风险。而且，这种简单是有代价的;流动性提供者放弃了很多灵活性，将这些资产的交易留给智能合约的规则....和套利者。

如果你愿意撸起袖子，Hummingbot Miner可能是一个更好的方式去捕获流动性挖矿奖励。你有能力定制你的交易，使用风险管理工具，并控制你的交易。参与Hummingbot Miner也是普通大众进入量化交易世界并在此过程中获得奖励的一种方式。

我们不断为我们的平台添加新的交易所和新的项目方，所以随着时间的推移，Hummingbot矿工也将能够参与越来越多样化的交易对和代币群体的活动。

## 如有任何问题获想参与讨论，请加入我们的社区

我们的社区有众多的做市商和套利者，他们愿意互相帮助，充分利用 Hummingbot。 您可以加入我们的 [Discord 中文频道](https://discord.gg/HgDExTAcWF)，讨论 Hummingbot、策略、流动性挖坑以及与加密货币世界有关的任何其他内容，并获得我们团队的直接支持。

加入中文微信群，请添加ID：amtf202004

更多教学互动视频，请订阅[bilibili频道](https://space.bilibili.com/2010395218/channel/detail?cid=178340)